{% extends 'base.html' %}
{% block title %}
    Welcome to terminal bashbord
{% endblock %}
{% block content %}
    <div class="position-relative overflow-hidden p-3 p-md-5 m-md-3 text-center bg-light">
             <div class="col-md-5 p-lg-5 mx-auto my-5">
            <h1 class="display-8 font-weight-normal">Ported Tutorial</h1>
            <p class="lead font-weight-normal">Start purchasing products by clicking the link below</p>
            <a class="btn btn-primary" href="{{ url_for('market_page') }}">Get Started</a>
        </div>
        <div class="product-device box-shadow d-none d-md-block"></div>
        <div class="product-device product-device-2 box-shadow d-none d-md-block"></div>
    </div>
{% endblock %}
